-------------------------------------------------------------------------------------------------------------------
------------------------------------ CREACI DE LES TAULES DE LA BASE DE DADES ------------------------------------
-------------------------------------------------------------------------------------------------------------------


------------------------------------------------ MDUL PRINCIPAL --------------------------------------------------

CREATE TABLE Marca
(
  idMarca			NUMBER			NOT NULL,
  nom				VARCHAR2(20)	NOT NULL,
 
  CONSTRAINT PK_Marca PRIMARY KEY (idMarca) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT UN_Marca UNIQUE (nom) USING INDEX TABLESPACE TFG_INDEX
)
TABLESPACE TFG_DADES;

CREATE TABLE Envas
(
  idEnvas			NUMBER			NOT NULL,
  tipus				VARCHAR2(20)	NOT NULL,

  CONSTRAINT PK_Envas PRIMARY KEY (idEnvas) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT UN_Envas UNIQUE (tipus) USING INDEX TABLESPACE TFG_INDEX
)
TABLESPACE TFG_DADES;

CREATE TABLE Format
(
  idFormat			NUMBER			NOT NULL,
  envas				NUMBER			NOT NULL,
  quantitat			VARCHAR2(8)		NOT NULL,

  CONSTRAINT PK_Format PRIMARY KEY (idFormat) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT UN_Format UNIQUE (envas, quantitat) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT FK_Format_Envas FOREIGN KEY (envas) REFERENCES Envas(idEnvas)
)
TABLESPACE TFG_DADES;

CREATE TABLE Presentacio
(
  idPresentacio		NUMBER			NOT NULL,
  tipus				VARCHAR2(50)	NOT NULL,

  CONSTRAINT PK_Presentacio PRIMARY KEY (idPresentacio) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT UN_Presentacio UNIQUE (tipus) USING INDEX TABLESPACE TFG_INDEX
)
TABLESPACE TFG_DADES;

CREATE TABLE Resposta
(
  idResposta		NUMBER			NOT NULL,
  registrat			CHAR(2)			NOT NULL,
  estat				VARCHAR2(20)	NOT NULL,

  CONSTRAINT PK_Resposta PRIMARY KEY (idResposta) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT UN_Resposta UNIQUE (registrat, estat) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT CK_Resposta CHECK ((registrat = 'SI' AND estat = 'REGISTRAT') OR (registrat = 'NO' AND estat IN('NO REGISTRAT', 'INCOMPLET')))
)
TABLESPACE TFG_DADES;

CREATE TABLE Moneda
(
  idMoneda			NUMBER			NOT NULL,
  nom				VARCHAR2(20)	NOT NULL,
  canviEuro			NUMBER			NOT NULL,

  CONSTRAINT PK_Moneda PRIMARY KEY (idMoneda) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT UN_Moneda UNIQUE (nom) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT CK_Moneda CHECK (canviEuro > 0)
)
TABLESPACE TFG_DADES;

CREATE TABLE Continent
(
  idContinent		NUMBER			NOT NULL,
  nom				VARCHAR2(50)	NOT NULL,

  CONSTRAINT PK_Continent PRIMARY KEY (idContinent) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT UN_Continent UNIQUE (nom) USING INDEX TABLESPACE TFG_INDEX
)
TABLESPACE TFG_DADES;

CREATE TABLE Pais
(
  idPais			NUMBER			NOT NULL,
  nom				VARCHAR2(50)	NOT NULL,
  continent			NUMBER			NOT NULL,
  moneda			NUMBER			NOT NULL,

  CONSTRAINT PK_Pais PRIMARY KEY (idPais) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT UN_Pais UNIQUE (nom) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT FK_Pais_Continent FOREIGN KEY (continent) REFERENCES Continent(idContinent),
  CONSTRAINT FK_Pais_Moneda FOREIGN KEY (moneda) REFERENCES Moneda(idMoneda)
)
TABLESPACE TFG_DADES;

CREATE TABLE Distribuidor
(
  idDistribuidor	NUMBER			NOT NULL,
  nom				VARCHAR2(100)	NOT NULL,
  pais				NUMBER			NOT NULL,
  esHomologat		CHAR(2)			NOT NULL,
  
  CONSTRAINT PK_Distribuidor PRIMARY KEY (idDistribuidor) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT UN_Distribuidor UNIQUE (nom, pais) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT FK_Dist_Pais FOREIGN KEY (pais) REFERENCES Pais(idPais),
  CONSTRAINT CK_Distribuidor CHECK (esHomologat IN('SI', 'NO'))
)
TABLESPACE TFG_DADES;

CREATE TABLE Producte
(
  idProducte		NUMBER			NOT NULL,
  nom				VARCHAR2(50)	NOT NULL,
  formula			VARCHAR2(20)	NOT NULL,
  format			NUMBER			NOT NULL,
  presentacio		NUMBER			NOT NULL,
  marca				NUMBER			NOT NULL,
  pais				NUMBER			NOT NULL, 
  distribuidor		NUMBER			NOT NULL, 
  registrat			NUMBER			DEFAULT 2	NOT NULL,
 
  CONSTRAINT PK_Producte PRIMARY KEY (idProducte) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT UN_Producte UNIQUE (nom, formula) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT FK_Prod_Format FOREIGN KEY (format) REFERENCES Format(idFormat),
  CONSTRAINT FK_Prod_Presentacio FOREIGN KEY (presentacio) REFERENCES Presentacio(idPresentacio),
  CONSTRAINT FK_Prod_Marca FOREIGN KEY (marca) REFERENCES Marca(idMarca),
  CONSTRAINT FK_Prod_Pais FOREIGN KEY (pais) REFERENCES Pais(idPais),
  CONSTRAINT FK_Prod_Dist FOREIGN KEY (distribuidor) REFERENCES Distribuidor(idDistribuidor),
  CONSTRAINT FK_Prod_Registre FOREIGN KEY (registrat) REFERENCES Resposta(idResposta)
)
TABLESPACE TFG_DADES;

CREATE TABLE Cost
(
  cost				NUMBER			NOT NULL,
  producte			NUMBER			NOT NULL,
  quantitat			NUMBER			NOT NULL,
  moneda			NUMBER			NOT NULL,

  CONSTRAINT FK_Cost_Producte FOREIGN KEY (producte) REFERENCES Producte(idProducte),  
  CONSTRAINT FK_Cost_Moneda FOREIGN KEY (moneda) REFERENCES Moneda(idMoneda),
  CONSTRAINT CK_Cost CHECK (quantitat > 0)
)
TABLESPACE TFG_DADES;

CREATE TABLE Registre
(
  idRegistre		NUMBER			NOT NULL,
  resposta			NUMBER			DEFAULT 2	NOT NULL,
  producte			NUMBER			NOT NULL, 
  pais				NUMBER			NOT NULL, 
  distribuidor		NUMBER			NOT NULL, 
  cost				NUMBER,
  dataInici			DATE			NOT NULL,
  dataFi			DATE,
  durada			NUMBER,

  CONSTRAINT PK_Registre PRIMARY KEY (idRegistre) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT FK_Reg_Resp FOREIGN KEY (resposta) REFERENCES Resposta(idResposta),
  CONSTRAINT FK_Reg_Prod FOREIGN KEY (producte) REFERENCES Producte(idProducte),
  CONSTRAINT FK_Reg_Pais FOREIGN KEY (pais) REFERENCES Pais(idPais),
  CONSTRAINT FK_Reg_Dist FOREIGN KEY (distribuidor) REFERENCES Distribuidor(idDistribuidor),
  CONSTRAINT CK_Reg_Cost CHECK (cost > 0),
  CONSTRAINT CK_Reg_Data CHECK (dataFi >= dataInici),
  CONSTRAINT CK_Reg_Durada CHECK (durada >= 0)
)
TABLESPACE TFG_DADES;


------------------------------------------------ MDUL ESTADSTIC -------------------------------------------------

CREATE TABLE Est1_Prod_Cost
(
  producte			NUMBER			NOT NULL,
  cost				NUMBER			NOT NULL,
  
  CONSTRAINT PK_Est1 PRIMARY KEY (producte) USING INDEX TABLESPACE TFG_INDEX
)
TABLESPACE TFG_DADES;

CREATE TABLE Est2_Paisos_Tram_Lent
(
  pais				NUMBER			NOT NULL,
  duradaTramit		NUMBER			NOT NULL,

  CONSTRAINT PK_Est2 PRIMARY KEY (pais) USING INDEX TABLESPACE TFG_INDEX
)
TABLESPACE TFG_DADES;

CREATE TABLE Est3_Temps_Mig
(
  pais				NUMBER			NOT NULL,  
  mPais				NUMBER			NOT NULL,
  
  CONSTRAINT PK_Est3 PRIMARY KEY (pais, mPais) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT FK_Est3_Pais FOREIGN KEY (pais) REFERENCES Pais(idPais)
)
TABLESPACE TFG_DADES;

CREATE TABLE Est4_Perc_Dist_Paisos
(
  paisNoDist		NUMBER(10,2)	NOT NULL,
  
  CONSTRAINT PK_Est4 PRIMARY KEY (paisNoDist) USING INDEX TABLESPACE TFG_INDEX
)
TABLESPACE TFG_DADES;

CREATE TABLE Est5_Mig_Reg_Pais
(
  pais				NUMBER			NOT NULL,  
  anys				NUMBER			NOT NULL,
  mRegistre			NUMBER			NOT NULL,
  
  CONSTRAINT PK_Est5 PRIMARY KEY (pais) USING INDEX TABLESPACE TFG_INDEX,
  CONSTRAINT FK_Est5_Pais FOREIGN KEY (pais) REFERENCES Pais(idPais)
)
TABLESPACE TFG_DADES;

CREATE TABLE Est6_Format_No_Reg
(
  formatNoReg		NUMBER(10,2)	NOT NULL,
  
  CONSTRAINT PK_Est6 PRIMARY KEY (formatNoReg) USING INDEX TABLESPACE TFG_INDEX
)
TABLESPACE TFG_DADES;


------------------------------------------------------ LOGS -------------------------------------------------------

CREATE TABLE Logs
(
  codi				NUMBER			NOT NULL,
  data				DATE			NOT NULL,
  procediment		VARCHAR2(50)	NOT NULL,
  paramsEntrada		VARCHAR2(200)	NOT NULL,
  paramsSortida		VARCHAR2(200)	NOT NULL,
 
  CONSTRAINT PK_Logs PRIMARY KEY (codi) USING INDEX TABLESPACE TFG_INDEX
)
TABLESPACE TFG_DADES;