CREATE OR REPLACE PROCEDURE SP_ALTA_LOGS (
	p_data				IN LOGS.data%TYPE,
	p_procediment		IN LOGS.procediment%TYPE,
	p_paramsEntrada		IN LOGS.paramsEntrada%TYPE,
	p_paramsSortida		IN LOGS.paramsSortida%TYPE
)
IS
/******************************************************************************
	Nom:				SP_ALTA_LOGS
	Propsit:			afegeix una entrada a la taula LOGS

	Parmetres entrada:	p_data, p_procediment, p_paramsEntrada, p_paramsSortida       

	Retorna:			'OK' si l'execuci ha finalitzat amb xit
						'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
RSP				VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

PRAGMA AUTONOMOUS_TRANSACTION;

BEGIN

paramsEntrada:=	'p_data: '||p_data||
				', p_procediment: '||p_procediment||
				', p_paramsEntrada: '||p_paramsEntrada||
				', p_paramsSortida: '||p_paramsSortida;

--Verifica que els camps obligatoris no siguin nuls
IF (p_data IS NULL) THEN 
	camp_nul:= 'data';
	RAISE E_NUL;
ELSIF (p_procediment IS NULL) THEN 
	camp_nul:= 'procediment';
	RAISE E_NUL;
ELSIF (p_paramsEntrada IS NULL) THEN 
	camp_nul:= 'paramsEntrada';
	RAISE E_NUL;     
ELSIF (p_paramsSortida IS NULL) THEN 
	camp_nul:= 'paramsSortida';
	RAISE E_NUL;     
END IF;
 
-- Inserta la nova entrada a la taula logs
INSERT INTO LOGS (data, procediment, paramsEntrada, paramsSortida)
VALUES (p_data, p_procediment, p_paramsEntrada, p_paramsSortida);
   
-- Finalitza amb xit
RSP:= 'OK';

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR LOG: el camp ' || camp_nul || ' no pot ser nul'; 
		INSERT INTO LOGS (data, procediment, paramsEntrada, paramsSortida)
		VALUES (to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_LOGS', p_paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		err_msg := SUBSTR (SQLERRM, 1, 200);
		RSP:= 'ERROR LOG: ' || err_msg;
		INSERT INTO LOGS (data, procediment, paramsEntrada, paramsSortida)
		VALUES (to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_LOGS', p_paramsEntrada, 'RSP: '||RSP);

END SP_ALTA_LOGS;