CREATE OR REPLACE PROCEDURE SP_ALTA_EST3 (
	p_pais				IN EST3_TEMPS_MIG.pais%TYPE,
	p_mPais				IN EST3_TEMPS_MIG.mPais%TYPE
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_EST3
   Propsit:            Afegeix una entrada a la taula estadstica EST3_TEMPS_MIG. 
                        La informaci introduda correspon al temps mig de registre 
						per pas.
                   
   Parmetres entrada:  - p_pais NUMBER: Identificador del pas.
						- p_mPais NUMBER: Temps mig de registre per pas.

   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
RSP				VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN

paramsEntrada:= 'p_pais: '||p_pais||
				', p_mPais: '||p_mPais;

--Verifica que els camps obligatoris no siguin nuls
IF (p_pais IS NULL) THEN 
	camp_nul:= 'pais';
	RAISE E_NUL;
ELSIF (p_mPais IS NULL) THEN 
	camp_nul:= 'mPais';
	RAISE E_NUL;
END IF;

-- Inserta la nova entrada a la taula EST3
INSERT INTO EST3_TEMPS_MIG(pais, mPais)
VALUES (p_pais, p_mPais);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST3', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR EST3: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST3', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
		err_msg := SUBSTR (SQLERRM, 1, 200);
		RSP:= 'ERROR EST3: ' || err_msg;
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST3', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);

END SP_ALTA_EST3;