CREATE OR REPLACE PROCEDURE SP_ALTA_EST4 (
	p_paisNoDist		IN EST4_PERC_DIST_PAISOS.paisNoDist%TYPE
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_EST4
   Propsit:            Afegeix una entrada a la taula estadstica EST4_PERC_DIST_PAISOS. 
                        La informaci introduda correspon al % de pasos que tenim a la
						BD que no tenen distribudor associat.
                   
   Parmetres entrada:  - p_paisNoDist NUMBER: % de pasos que no tenen distribudor associat.

   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
RSP				VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN

paramsEntrada:= 'p_paisNoDist: '||p_paisNoDist;

--Verifica que els camps obligatoris no siguin nuls
IF (p_paisNoDist IS NULL) THEN 
	camp_nul:= 'paisNoDist';
	RAISE E_NUL;
END IF;

-- Inserta la nova entrada a la taula EST4
INSERT INTO EST4_PERC_DIST_PAISOS(paisNoDist)
VALUES (p_paisNoDist);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST4', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR EST4: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST4', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
		err_msg := SUBSTR (SQLERRM, 1, 200);
		RSP:= 'ERROR EST4: ' || err_msg;
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST4', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);

END SP_ALTA_EST4;