CREATE OR REPLACE PROCEDURE SP_MODIFICACIO_EST4
IS
/******************************************************************************
   Nom:                 SP_MODIFICACIO_EST4
   Propsit:            Actualitza la taula estadstica EST4_PERC_DIST_PAISOS.
                        La informaci actualitzada correspon al % de pasos 
						que tenim a la BD que no tenen distribudor associat.
                   
   Parmetres entrada:  sense parmetres.

   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
RSP				VARCHAR2 (500);
err_msg			VARCHAR2 (500);
paisDist		NUMBER;
paisTotal		NUMBER;

BEGIN

paramsEntrada:= 'sense parmetres';

--Esborra les dades de la taula EST4
DELETE FROM EST4_PERC_DIST_PAISOS;

--Comptem el total de pasos que hi ha a la Base de Dades
SELECT COUNT (*) INTO paisTotal
	FROM pais;

--Comprova els pasos que tenen distribudor associat
SELECT COUNT (*) INTO paisDist
	FROM PAIS p, DISTRIBUIDOR d
	WHERE p.idPais = d.pais;
	
--Inserim el percentatge de pasos que tenim a la BD que no tenen distribudor associat
INSERT INTO EST4_PERC_DIST_PAISOS
	VALUES((paisTotal - paisDist) / paisTotal);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_EST4', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION
	
	WHEN OTHERS THEN
		ROLLBACK;
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR EST4: el percentatge no ha variat.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MARCA', paramsEntrada, 'RSP: '||RSP);
		
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR EST4: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_EST6', paramsEntrada, 'RSP: '||RSP);
			DBMS_OUTPUT.PUT_LINE(RSP);
		END IF;

END SP_MODIFICACIO_EST4;