CREATE OR REPLACE PROCEDURE SP_ALTA_EST5 (
	p_pais				IN EST5_MIG_REG_PAIS.pais%TYPE,
	p_anys				IN EST5_MIG_REG_PAIS.anys%TYPE,
	p_mRegistre			IN EST5_MIG_REG_PAIS.mRegistre%TYPE
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_EST5
   Propsit:            Afegeix una entrada a la taula estadstica EST5_MIG_REG_PAIS. 
                        Donat un any concret: el nmero mig de registres per pas.
                   
   Parmetres entrada:  - p_pais NUMBER: Identificador del pas.
						- p_anys NUMBER: Any concret demanat.
						- p_mRegistre NUMBER: Temps mig de registre per pas.

   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
RSP				VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN

paramsEntrada:= 'p_pais: '||p_pais||
				', p_anys: '||p_anys||
				', p_mRegistre: '||p_mRegistre;

--Verifica que els camps obligatoris no siguin nuls
IF (p_pais IS NULL) THEN 
	camp_nul:= 'pais';
	RAISE E_NUL;
ELSIF (p_anys IS NULL) THEN 
	camp_nul:= 'anys';
	RAISE E_NUL;   
ELSIF (p_mRegistre IS NULL) THEN 
	camp_nul:= 'mRegistre';
	RAISE E_NUL;
END IF;

-- Inserta la nova entrada a la taula EST3
INSERT INTO EST5_MIG_REG_PAIS(pais, anys, mRegistre)
VALUES (p_pais, p_anys, p_mRegistre);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST5', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR EST5: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST5', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
		err_msg := SUBSTR (SQLERRM, 1, 200);
		RSP:= 'ERROR EST5: ' || err_msg;
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST5', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);

END SP_ALTA_EST5;