CREATE OR REPLACE PROCEDURE SP_MODIFICACIO_EST5 (
	p_pais				IN EST5_MIG_REG_PAIS.pais%TYPE,
	p_anys				IN EST5_MIG_REG_PAIS.anys%TYPE
)
IS
/******************************************************************************
   Nom:                 SP_MODIFICACIO_EST5
   Propsit:            Actualitza la taula estadstica EST5_MIG_REG_PAIS. 
                        La informaci introduda correspon al nmero mig de 
						registres per pas un any determinat. 
                   
   Parmetres entrada:  - p_pais NUMBER: Identificador del pas.
						- p_anys NUMBER: Any concret demanat.

   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
RSP				VARCHAR2 (500);
err_msg			VARCHAR2 (500);
num_mesos		NUMBER;
reg_total		NUMBER;
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN

paramsEntrada:= 'p_pais: '||p_pais||
				', p_anys: '||p_anys;

--Verifica que els camps obligatoris no siguin nuls
IF (p_pais IS NULL) THEN 
	camp_nul:= 'pais';
	RAISE E_NUL;
ELSIF (p_anys IS NULL) THEN 
	camp_nul:= 'anys';
	RAISE E_NUL;   
END IF;

--Calcula els registres totals per pas
SELECT SUM(pais) INTO reg_total
	FROM REGISTRE
	WHERE pais = p_pais AND EXTRACT(year FROM dataFi) = p_anys;

--Calcula la suma del nombre de mesos en que s'han registrat productes.
SELECT COUNT (COUNT(*)) INTO num_mesos
	FROM REGISTRE
	WHERE pais = p_pais AND EXTRACT(year FROM dataFi) = p_anys
	GROUP BY pais, EXTRACT(month from dataFi);
   
--Actualitza nmero mig de registres per pas 
UPDATE EST5_MIG_REG_PAIS
	SET mRegistre = ROUND(reg_total/num_mesos, 2)
	WHERE pais = p_pais AND anys = p_anys;

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_EST5', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR EST5: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_EST5', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
		err_msg := SUBSTR (SQLERRM, 1, 200);
		RSP:= 'ERROR EST5: ' || err_msg;
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_EST5', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);

END SP_MODIFICACIO_EST5;