CREATE OR REPLACE PROCEDURE SP_ALTA_EST6 (
	p_formatNoReg			IN EST6_FORMAT_NO_REG.formatNoReg%TYPE
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_EST6
   Propsit:            Afegeix una entrada a la taula estadstica EST6_FORMAT_NO_REG. 
                        La informaci introduda correspon al % de format de producte
						que mai shan registrat.
                   
   Parmetres entrada:  - p_formatNoReg NUMBER: % de formatNoRegs de producte que mai shan registrat.

   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
RSP				VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN

paramsEntrada:= 'p_formatNoReg: '||p_formatNoReg;

--Verifica que els camps obligatoris no siguin nuls
IF (p_formatNoReg IS NULL) THEN 
	camp_nul:= 'formatNoReg';
	RAISE E_NUL;
END IF;

-- Inserta la nova entrada a la taula EST6
INSERT INTO EST6_FORMAT_NO_REG(formatNoReg)
VALUES (p_formatNoReg);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST6', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR EST6: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST6', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
		err_msg := SUBSTR (SQLERRM, 1, 200);
		RSP:= 'ERROR EST6: ' || err_msg;
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST6', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);

END SP_ALTA_EST6;