CREATE OR REPLACE PROCEDURE SP_MODIFICACIO_EST6
IS
/******************************************************************************
   Nom:                 SP_MODIFICACIO_EST6
   Propsit:            Actualitza la taula estadstica EST6_FORMAT_NO_REG.
                        La informaci actualitzada correspon al % de formats 
						de producte que mai s'han registrat.
                   
   Parmetres entrada:  sense parmetres.

   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
RSP				VARCHAR2 (500);
err_msg			VARCHAR2 (500);
formatReg		NUMBER;
formatTotal		NUMBER;

BEGIN

paramsEntrada:= 'sense parmetres';

--Esborra les dades de la taula EST6
DELETE FROM EST6_FORMAT_NO_REG;

--Comptem el total de formats que hi ha a la Base de Dades
SELECT COUNT (*) INTO formatTotal
	FROM format;

--Comprova els formats registrats
SELECT COUNT(DISTINCT format) INTO formatReg
	FROM PRODUCTE
	WHERE registrat = 1;
	
--Inserim el percentatge de formats de producte que mai s'han registrat
INSERT INTO EST6_FORMAT_NO_REG
	VALUES((formatTotal - formatReg) / formatTotal);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_EST6', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION
	
	WHEN OTHERS THEN
		ROLLBACK;
		
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR EST6: el percentatge no ha variat.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MARCA', paramsEntrada, 'RSP: '||RSP);
		
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR EST6: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_EST6', paramsEntrada, 'RSP: '||RSP);
			DBMS_OUTPUT.PUT_LINE(RSP);
		END IF;

END SP_MODIFICACIO_EST6;