CREATE OR REPLACE PROCEDURE SP_ALTA_EST1 (
	p_producte			IN EST1_PROD_COST.producte%TYPE,
	p_cost				IN EST1_PROD_COST.cost%TYPE
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_EST1
   Propsit:            Afegeix una entrada a la taula estadstica EST1_PROD_COST. 
                        La informaci introduda correspon al registre dels productes
                        costat ms registrar en euros ().
                   
   Parmetres entrada:  - p_producte NUMBER: Identificador del producte.
						- p_cost NUMBER: Cost total del producte.

   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
RSP				VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN

paramsEntrada:= 'p_producte: '||p_producte||
				', p_cost: '||p_cost;

--Verifica que els camps obligatoris no siguin nuls
IF (p_producte IS NULL) THEN 
	camp_nul:= 'producte';
	RAISE E_NUL;
ELSIF (p_cost IS NULL) THEN 
	camp_nul:= 'cost';
	RAISE E_NUL;
END IF;

-- Inserta la nova entrada a la taula EST1
INSERT INTO EST1_PROD_COST (producte, cost)
VALUES (p_producte, p_cost);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST1', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR EST1: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST1', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
		err_msg := SUBSTR (SQLERRM, 1, 200);
		RSP:= 'ERROR EST1: ' || err_msg;
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST1', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);

END SP_ALTA_EST1;