CREATE OR REPLACE PROCEDURE SP_ALTA_EST2 (
	p_pais				IN EST2_PAISOS_TRAM_LENT.pais%TYPE,
	p_duradaTramit		IN EST2_PAISOS_TRAM_LENT.duradaTramit%TYPE
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_EST2
   Propsit:            Afegeix una entrada a la taula estadstica EST2_PAISOS_TRAM_LENT. 
                        La informaci introduda correspon als pasos on els trmits sn 
						ms lents.
                   
   Parmetres entrada:  - p_pais NUMBER: Identificador del pas.
						- p_duradaTramit NUMBER: Durada del registre.

   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
RSP				VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN

paramsEntrada:= 'p_pais: '||p_pais||
				', p_duradaTramit: '||p_duradaTramit;

--Verifica que els camps obligatoris no siguin nuls
IF (p_pais IS NULL) THEN 
	camp_nul:= 'pais';
	RAISE E_NUL;
ELSIF (p_duradaTramit IS NULL) THEN 
	camp_nul:= 'duradaTramit';
	RAISE E_NUL;
END IF;

-- Inserta la nova entrada a la taula EST2
INSERT INTO EST2_PAISOS_TRAM_LENT (pais, duradaTramit)
VALUES (p_pais, p_duradaTramit);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST2', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR EST2: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST2', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
		err_msg := SUBSTR (SQLERRM, 1, 200);
		RSP:= 'ERROR EST2: ' || err_msg;
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_EST2', paramsEntrada, 'RSP: '||RSP);
		DBMS_OUTPUT.PUT_LINE(RSP);

END SP_ALTA_EST2;