CREATE OR REPLACE PROCEDURE SP_BAIXA_MARCA (
	p_idMarca			IN MARCA.idMarca%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_BAIXA_MARCA
   Propsit:            elimina una marca de la taula MARCA 
                   
   Parmetres entrada:  - p_idMarca NUMBER: Identificador de la marca
   
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN

paramsEntrada:= 'p_idMarca: '||p_idMarca;

--Verifica que els camps obligatoris no siguin nuls
IF (p_idMarca IS NULL) THEN 
	camp_nul:= 'idMarca';
	RAISE E_NUL;
END IF;

--Verifica que existeix la marca
SELECT COUNT (*) INTO existeix
	FROM MARCA
	WHERE idMarca = p_idMarca;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Elimina la marca
DELETE FROM MARCA WHERE idMarca = p_idMarca;

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MARCA', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MARCA', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: la marca no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MARCA', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -02292) THEN
			RSP:= 'ERROR: no es pot esborrar la marca perqu est relacionada amb algun producte existent.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MARCA', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MARCA', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_BAIXA_MARCA;