CREATE OR REPLACE PROCEDURE SP_MODIFICACIO_ENVAS (
	p_idEnvas			IN ENVAS.idEnvas%TYPE,
	p_tipus				IN ENVAS.tipus%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:					SP_MODIFICACIO_ENVAS
   Propsit:            modifica dades d'un envs a la taula ENVAS 
                   
   Parmetres entrada:  p_idEnvas NUMBER: Identificador de lenvs.
						p_tipus VARCHAR2(20): Tipus de lenvs.
						
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN

paramsEntrada:= 'p_idEnvas: '||p_idEnvas||
				', p_tipus: '||p_tipus;

--Verifica que els camps obligatoris no siguin nuls
IF (p_idEnvas IS NULL) THEN 
	camp_nul:= 'idEnvas';
	RAISE E_NUL;
ELSIF (p_tipus IS NULL) THEN 
	camp_nul:= 'tipus';
	RAISE E_NUL;
END IF;

--Verifica que existeix l'envs
SELECT COUNT (*) INTO existeix
	FROM ENVAS
	WHERE idEnvas = p_idEnvas;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Modifica les dades de l'envs
UPDATE ENVAS
	SET tipus = p_tipus
	WHERE idEnvas = p_idEnvas;

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_ENVAS', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul';  
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_ENVAS', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: lenvs no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_ENVAS', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix un envs amb el mateix: tipus.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_ENVAS', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_ENVAS', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_MODIFICACIO_ENVAS;