CREATE OR REPLACE PROCEDURE SP_ALTA_FORMAT (
	p_envas				IN FORMAT.envas%TYPE,
	p_quantitat			IN FORMAT.quantitat%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_FORMAT
   Propsit:            afegeix un nou format a la taula FORMAT 
                   
   Parmetres entrada:  - p_envas NUMBER: tipus denvs.
                        - p_quantitat VARCHAR2(8): quantitat de producte.

   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
ref_err			VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_FK			EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_envas: '||p_envas||
				', p_quantitat: '||p_quantitat;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_envas IS NULL) THEN 
	camp_nul:= 'envas';
	RAISE E_NUL;
ELSIF (p_quantitat IS NULL) THEN 
	camp_nul:= 'quantitat';
	RAISE E_NUL;
END IF;

--Verifica que existeix l'envs
SELECT COUNT (*) INTO existeix
	FROM ENVAS
	WHERE idEnvas = p_envas;
	
	IF (existeix = 0) THEN
		ref_err:= 'envas'; 
		RAISE E_NO_FK;
	END IF;

-- Inserta el nou format
INSERT INTO FORMAT (envas, quantitat)
VALUES (p_envas, p_quantitat);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_FORMAT', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_FORMAT', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_FK THEN
		RSP:= 'ERROR: ' || ref_err || ' no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_FORMAT', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix un format amb el mateix: envas.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_FORMAT', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_FORMAT', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_ALTA_FORMAT;