CREATE OR REPLACE PROCEDURE SP_BAIXA_FORMAT (
	p_idFormat			IN FORMAT.idFormat%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_BAIXA_FORMAT
   Propsit:            elimina un format de la taula FORMAT 
                   
   Parmetres entrada:  - p_idFormat NUMBER: identificador del format
   
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN

paramsEntrada:= 'p_idFormat: '||p_idFormat;

--Verifica que els camps obligatoris no siguin nuls
IF (p_idFormat IS NULL) THEN 
	camp_nul:= 'idFormat';
	RAISE E_NUL;
END IF;

--Verifica que existeix el format
SELECT COUNT (*) INTO existeix
	FROM FORMAT
	WHERE idFormat = p_idFormat;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Elimina el format
DELETE FROM FORMAT WHERE idFormat = p_idFormat;

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_FORMAT', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_FORMAT', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: el format no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_FORMAT', paramsEntrada, 'RSP: '||RSP);

WHEN OTHERS THEN
	ROLLBACK;
	
		IF (SQLCODE = -02292) THEN
			RSP:= 'ERROR: no es pot esborrar el format perqu est relacionada amb algun producte existent.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_FORMAT', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_FORMAT', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_BAIXA_FORMAT;