CREATE OR REPLACE PROCEDURE SP_MODIFICACIO_FORMAT (
	p_idFormat			IN FORMAT.idFormat%TYPE,
	p_envas				IN FORMAT.envas%TYPE,
	p_quantitat			IN FORMAT.quantitat%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_MODIFICACIO_FORMAT
   Propsit:            modifica dades d'un format a la taula FORMAT 
                   
   Parmetres entrada:  - p_idFormat NUMBER: identificador del format
						- p_envas NUMBER: tipus denvs.
                        - p_quantitat VARCHAR2(8): quantitat de producte.
						
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;
E_NO_FK			EXCEPTION;

BEGIN

paramsEntrada:= 'p_idFormat: '||p_idFormat||
				', p_envas: '||p_envas||
				', p_quantitat: '||p_quantitat;

--Verifica que els camps obligatoris no siguin nuls
IF (p_idFormat IS NULL) THEN 
	camp_nul:= 'idFormat';
	RAISE E_NUL;
ELSIF (p_envas IS NULL) THEN 
	camp_nul:= 'envas';
	RAISE E_NUL;
ELSIF (p_quantitat IS NULL) THEN 
	camp_nul:= 'quantitat';
	RAISE E_NUL;
END IF;

--Verifica que existeix el format
SELECT COUNT (*) INTO existeix
	FROM FORMAT
	WHERE idFormat = p_idFormat;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

--Verifica que existeix l'envs
SELECT COUNT (*) INTO existeix
	FROM ENVAS
	WHERE idEnvas = p_envas;
	
	IF (existeix = 0) THEN
		RAISE E_NO_FK;
	END IF;

-- Modifica les dades del format
UPDATE FORMAT
	SET envas = p_envas,
		quantitat = p_quantitat
WHERE idFormat = p_idFormat;

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_FORMAT', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul';  
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_FORMAT', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: el format no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_FORMAT', paramsEntrada, 'RSP: '||RSP);
		
	WHEN E_NO_FK THEN
		RSP:= 'ERROR: lenvs no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_FORMAT', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix un format amb el mateix: envas, quantitat.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_FORMAT', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_FORMAT', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_MODIFICACIO_FORMAT;