CREATE OR REPLACE PROCEDURE SP_ALTA_PRESENTACIO (
	p_tipus				IN PRESENTACIO.tipus%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:					SP_ALTA_PRESENTACIO
   Propsit:            afegeix una nova presentaci a la taula PRESENTACIO 
                   
   Parmetres entrada:  - p_tipus VARCHAR2(20): tipus de presentaci

   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_tipus: '||p_tipus;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_tipus IS NULL) THEN 
	camp_nul:= 'tipus';
	RAISE E_NUL;
END IF;

-- Inserta la nova presentaci
INSERT INTO PRESENTACIO (tipus)
VALUES (p_tipus);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix una presentaci amb el mateix: tipus.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_ALTA_PRESENTACIO;