CREATE OR REPLACE PROCEDURE SP_BAIXA_PRESENTACIO (
	p_idPRESENTACIO			IN PRESENTACIO.idPresentacio%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_BAIXA_PRESENTACIO
   Propsit:            elimina una presentaci de la taula PRESENTACIO 
                   
   Parmetres entrada:  - p_idPresentacio NUMBER: identificador de la presentaci
   
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN

paramsEntrada:= 'p_idPresentacio: '||p_idPresentacio;

--Verifica que els camps obligatoris no siguin nuls
IF (p_idPresentacio IS NULL) THEN
	camp_nul:= 'idPresentacio';
	RAISE E_NUL;
END IF;

--Verifica que existeix la presentaci
SELECT COUNT (*) INTO existeix
	FROM PRESENTACIO
	WHERE idPresentacio = p_idPresentacio;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Elimina la presentaci
DELETE FROM PRESENTACIO WHERE idPresentacio = p_idPresentacio;

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: la presentaci no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -02292) THEN
			RSP:= 'ERROR: no es pot esborrar la presentaci perqu est relacionat amb algun producte existent.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_BAIXA_PRESENTACIO;