CREATE OR REPLACE PROCEDURE SP_MODIFICACIO_PRESENTACIO (
	p_idPresentacio		IN PRESENTACIO.idPresentacio%TYPE,
	p_tipus				IN PRESENTACIO.tipus%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:					SP_MODIFICACIO_PRESENTACIO
   Propsit:            modifica dades d'una presentaci a la taula PRESENTACIO 
                   
   Parmetres entrada:  - p_idPresentacio NUMBER: identificador de la presentaci
						- p_tipus VARCHAR2(20): tipus de presentaci
						
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN

paramsEntrada:= 'p_idPresentacio: '||p_idPresentacio||
				', p_tipus: '||p_tipus;

--Verifica que els camps obligatoris no siguin nuls
IF (p_idPresentacio IS NULL) THEN 
	camp_nul:= 'idPresentacio';
	RAISE E_NUL;
ELSIF (p_tipus IS NULL) THEN 
	camp_nul:= 'tipus';
	RAISE E_NUL;
END IF;

--Verifica que existeix la presentaci
SELECT COUNT (*) INTO existeix
	FROM PRESENTACIO
	WHERE idPresentacio = p_idPresentacio;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Modifica les dades de la presentaci
UPDATE PRESENTACIO
	SET tipus = p_tipus
	WHERE idPresentacio = p_idPresentacio;

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul';  
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: la presentaci no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix un presentaci amb el mateix: tipus.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_PRESENTACIO', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_MODIFICACIO_PRESENTACIO;