CREATE OR REPLACE PROCEDURE SP_ALTA_RESPOSTA (
	p_registrat			IN RESPOSTA.registrat%TYPE,
	p_estat				IN RESPOSTA.estat%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_RESPOSTA
   Propsit:            afegeix una nova resposta a la taula RESPOSTA 
                   
   Parmetres entrada:  - p_registrat CHAR(2): estat del registre (Si/No).
                        - p_estat VARCHAR2(20): resposta del registre.

   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_registrat: '||p_registrat||
				', p_estat: '||p_estat;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_registrat IS NULL) THEN 
	camp_nul:= 'registrat';
	RAISE E_NUL;
ELSIF (p_estat IS NULL) THEN 
	camp_nul:= 'estat';
	RAISE E_NUL;
END IF;

-- Inserta la nova resposta
INSERT INTO RESPOSTA (registrat, estat)
VALUES (p_registrat, p_estat);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_RESPOSTA', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_RESPOSTA', paramsEntrada, 'RSP: '||RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix una resposta amb el mateix: registrat, estat.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_RESPOSTA', paramsEntrada, 'RSP: '||RSP);
			
		ELSIF (SQLCODE = -02290) THEN 
			RSP:= 'ERROR: el valor dels camps s incorrecte';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_RESPOSTA', paramsEntrada, 'RSP: '||RSP); 
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_RESPOSTA', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_ALTA_RESPOSTA;