CREATE OR REPLACE PROCEDURE SP_ALTA_MONEDA (
	p_nom				IN MONEDA.nom%TYPE,
	p_canviEuro			IN MONEDA.canviEuro%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_MONEDA
   Propsit:            afegeix una nova moneda a la taula MONEDA 
                   
   Parmetres entrada:  - p_nom VARCHAR2(20): Nom de la moneda.
                        - p_canviEuro NUMBER: Canvi d'euro () a la moneda local.

   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_nom: '||p_nom||
				', p_canviEuro: '||p_canviEuro;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_nom IS NULL) THEN 
	camp_nul:= 'nom';
	RAISE E_NUL;
ELSIF (p_canviEuro IS NULL) THEN 
	camp_nul:= 'canviEuro';
	RAISE E_NUL;
END IF;

-- Inserta la nova moneda
INSERT INTO MONEDA (nom, canviEuro)
VALUES (p_nom, p_canviEuro);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_MONEDA', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_MONEDA', paramsEntrada, 'RSP: '||RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix una moneda amb el mateix: nom.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_MONEDA', paramsEntrada, 'RSP: '||RSP);
			
		ELSIF (SQLCODE = -02290) THEN 
			RSP:= 'ERROR: el valor del camp canviEuro ha de ser positiu';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_MONEDA', paramsEntrada, 'RSP: '||RSP); 
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_MONEDA', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_ALTA_MONEDA;