CREATE OR REPLACE PROCEDURE SP_BAIXA_MONEDA (
	p_idMoneda			IN MONEDA.idMoneda%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_BAIXA_MONEDA
   Propsit:            elimina una moneda a la taula MONEDA 
                   
   Parmetres entrada:  - p_idMoneda NUMBER: Identificador de moneda.

   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN

paramsEntrada:= 'p_idMoneda: '||p_idMoneda;

--Verifica que els camps obligatoris no siguin nuls
IF (p_idMoneda IS NULL) THEN 
	camp_nul:= 'idMoneda';
	RAISE E_NUL;
END IF;

--Verifica que existeix la moneda
SELECT COUNT (*) INTO existeix
	FROM MONEDA
	WHERE idMoneda = p_idMoneda;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Elimina la moneda
DELETE FROM MONEDA WHERE idMoneda = p_idMoneda;

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MONEDA', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MONEDA', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: la moneda no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MONEDA', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
	ROLLBACK;
		IF (SQLCODE = -02292) THEN
			RSP:= 'ERROR: no es pot esborrar la moneda perqu est relacionada amb algun producte existent.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MONEDA', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_MONEDA', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_BAIXA_MONEDA;