CREATE OR REPLACE PROCEDURE SP_MODIFICACIO_MONEDA (
	p_idMoneda			IN MONEDA.idMoneda%TYPE,
	p_nom				IN MONEDA.nom%TYPE,
	p_canviEuro			IN MONEDA.canviEuro%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_MODIFICACIO_MONEDA
   Propsit:            modifica dades d'una moneda a la taula MONEDA  
                   
   Parmetres entrada:  - p_idMoneda NUMBER: identificador de la moneda
						- p_nom VARCHAR2(20): nom de la moneda.
                        - p_canviEuro NUMBER: canvi de euro () a la moneda local.
						
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN

paramsEntrada:= 'p_idMoneda: '||p_idMoneda||
				', p_nom: '||p_nom||
				', p_canviEuro: '||p_canviEuro;

--Verifica que els camps obligatoris no siguin nuls
IF (p_idMoneda IS NULL) THEN 
	camp_nul:= 'idMoneda';
	RAISE E_NUL;
ELSIF (p_nom IS NULL) THEN 
	camp_nul:= 'nom';
	RAISE E_NUL;
ELSIF (p_canviEuro IS NULL) THEN 
	camp_nul:= 'p_canviEuro';
	RAISE E_NUL;
END IF;

--Verifica que existeix la moneda
SELECT COUNT (*) INTO existeix
	FROM MONEDA
	WHERE idMoneda = p_idMoneda;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Modifica les dades de la moneda
UPDATE MONEDA
	SET nom = p_nom,
		canviEuro = p_canviEuro
WHERE idMoneda = p_idMoneda;

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_MONEDA', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul';  
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_MONEDA', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: la moneda no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_MONEDA', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix una moneda amb el mateix: nom.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_MONEDA', paramsEntrada, 'RSP: '||RSP);
			
		ELSIF (SQLCODE = -02290) THEN 
			RSP:= 'ERROR: el valor del camp canviEuro ha de ser positiu';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_MONEDA', paramsEntrada, 'RSP: '||RSP); 
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_FORMAT', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_MODIFICACIO_MONEDA;