CREATE OR REPLACE PROCEDURE SP_ALTA_COST (
	p_producte			IN COST.producte%TYPE,
	p_quantitat			IN COST.quantitat%TYPE,
	p_moneda			IN COST.moneda%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_COST
   Propsit:            afegeix un nou cost a la taula COST calculant el canvi
						d'euro () a moneda local. Es realitza per a cada 
						producte registrat.
                   
   Parmetres entrada:  - p_producte NUMBER: Identificador del producte.
						- p_quantitat NUMBER: Cost del registre en euro ().
						- p_moneda VARCHAR2(20): Nom de la moneda.

   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
ref_err			VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_FK			EXCEPTION;
canvi			NUMBER;

BEGIN
   
paramsEntrada:= 'p_producte: '||p_producte||
				', p_quantitat: '||p_quantitat||
				', p_moneda: '||p_moneda;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_producte IS NULL) THEN 
	camp_nul:= 'producte';
	RAISE E_NUL;
ELSIF (p_quantitat IS NULL) THEN 
	camp_nul:= 'quantitat';
	RAISE E_NUL;
ELSIF (p_moneda IS NULL) THEN 
	camp_nul:= 'moneda';
	RAISE E_NUL;
END IF;

--Verifica que existeix el producte
SELECT COUNT (*) INTO existeix
	FROM PRODUCTE
	WHERE idProducte = p_producte;
	
	IF (existeix = 0) THEN
		ref_err:= 'producte'; 
		RAISE E_NO_FK;
	END IF;

--Verifica que existeix la moneda
SELECT COUNT (*) INTO existeix
	FROM MONEDA
	WHERE idMoneda = p_moneda;
	
	IF (existeix = 0) THEN
		ref_err:= 'moneda'; 
		RAISE E_NO_FK;
	END IF;
	
--Calcula el cost en moneda local
SELECT canviEuro INTO canvi
	FROM MONEDA
	WHERE idMoneda = p_moneda;

	canvi :=  canvi * p_quantitat;

-- Inserta el nou cost
INSERT INTO COST (cost, producte, quantitat, moneda)
VALUES (canvi, p_producte, p_quantitat, p_moneda);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_COST', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_COST', paramsEntrada, 'RSP: '||RSP);
		
	WHEN E_NO_FK THEN
		RSP:= 'ERROR: ' || ref_err || ' no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_COST', paramsEntrada, 'RSP: '||RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -02290) THEN 
			RSP:= 'ERROR: el valor del camp quantitat ha de ser positiu';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_COST', paramsEntrada, 'RSP: '||RSP); 
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_COST', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_ALTA_COST;