CREATE OR REPLACE PROCEDURE SP_ALTA_CONTINENT (
	p_nom				IN CONTINENT.nom%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_CONTINENT
   Propsit:            afegeix un nou continent a la taula CONTINENT 
                   
   Parmetres entrada:  - p_nom VARCHAR2(20): nom del continent.

   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_nom: '||p_nom;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_nom IS NULL) THEN 
	camp_nul:= 'nom';
	RAISE E_NUL;
END IF;

-- Inserta el nou continent
INSERT INTO CONTINENT (nom)
VALUES (p_nom);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_CONTINENT', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_CONTINENT', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix un continent amb el mateix: nom.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_CONTINENT', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_CONTINENT', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_ALTA_CONTINENT;