CREATE OR REPLACE PROCEDURE SP_ALTA_PAIS (
	p_nom				IN PAIS.nom%TYPE,
	p_continent			IN PAIS.continent%TYPE,
	p_moneda			IN PAIS.moneda%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_PAIS
   Propsit:            afegeix un nou pais a la taula PAIS 
                   
   Parmetres entrada:  - p_nom VARCHAR2(20): nom del pais.
                        - p_continent NUMBER: identificador del continent.
						- p_moneda NUMBER: identificador de la moneda.

   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
ref_err			VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_FK			EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_nom: '||p_nom||
				', p_continent: '||p_continent||
				', p_moneda: '||p_moneda;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_nom IS NULL) THEN 
	camp_nul:= 'nom';
	RAISE E_NUL;
ELSIF (p_continent IS NULL) THEN 
	camp_nul:= 'continent';
	RAISE E_NUL;
ELSIF (p_moneda IS NULL) THEN 
	camp_nul:= 'moneda';
	RAISE E_NUL;
END IF;

--Verifica que existeix el continent
SELECT COUNT (*) INTO existeix
	FROM CONTINENT
	WHERE idContinent = p_continent;
	
	IF (existeix = 0) THEN
		ref_err:= 'continent'; 
		RAISE E_NO_FK;
	END IF;
	
--Verifica que existeix la moneda
SELECT COUNT (*) INTO existeix
	FROM MONEDA
	WHERE idMoneda = p_moneda;
	
	IF (existeix = 0) THEN
		ref_err:= 'moneda'; 
		RAISE E_NO_FK;
	END IF;

-- Inserta el nou pais
INSERT INTO PAIS (nom, continent, moneda)
VALUES (p_nom, p_continent, p_moneda);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_PAIS', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_PAIS', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_FK THEN
		RSP:= 'ERROR: ' || ref_err || ' no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_PAIS', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix un pais amb el mateix: nom.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_PAIS', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_PAIS', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_ALTA_PAIS;