CREATE OR REPLACE PROCEDURE SP_BAIXA_DISTRIBUIDOR (
	p_idDistribuidor	IN DISTRIBUIDOR.idDistribuidor%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_BAIXA_DISTRIBUIDOR
   Propsit:            elimina un distribudor a la taula DISTRIBUIDOR
                   
   Parmetres entrada:  - p_idDistribuidor NUMBER: identificador del distribuidor.
						
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_idDistribuidor: '||p_idDistribuidor;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_idDistribuidor IS NULL) THEN 
	camp_nul:= 'idDistribuidor';
	RAISE E_NUL;
END IF;

--Verifica que existeix el distribudor
SELECT COUNT (*) INTO existeix
	FROM DISTRIBUIDOR
	WHERE idDistribuidor = p_idDistribuidor;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Elimina el distribudor
DELETE FROM DISTRIBUIDOR WHERE idDistribuidor = p_idDistribuidor;

--------------------------------------------------------------------------------------
-- 									ACTUALITZA EST4 								--
--------------------------------------------------------------------------------------

--Actualitza la taula EST4 un cop donat de baixa el distribudor
SP_MODIFICACIO_EST4(); 
--------------------------------------------------------------------------------------

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP);
		
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: el distribudor no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -02292) THEN
			RSP:= 'ERROR: no es pot esborrar el distribudor perqu est relacionat amb algun registre existent.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_BAIXA_DISTRIBUIDOR;