CREATE OR REPLACE PROCEDURE SP_MODIFICACIO_DISTRIBUIDOR (
	p_idDistribuidor	IN DISTRIBUIDOR.idDistribuidor%TYPE,
	p_nom				IN DISTRIBUIDOR.nom%TYPE,
	p_pais				IN DISTRIBUIDOR.pais%TYPE,
	p_esHomologat		IN DISTRIBUIDOR.esHomologat%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_MODIFICACIO_DISTRIBUIDOR
   Propsit:            modifica un distribudor a la taula DISTRIBUIDOR 
                   
   Parmetres entrada:  - p_idDistribuidor NUMBER: identificador del distribudor.
						- p_nom VARCHAR2(100): nom del distribudor.
                        - p_pais NUMBER: identificador del pais.
						- p_esHomologat CHAR(2): indica si el distribudor esta homologat al pas.

   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_idDistribuidor: '||p_idDistribuidor||
				', p_nom: '||p_nom||
				', p_pais: '||p_pais||
				', p_esHomologat: '||p_esHomologat;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_idDistribuidor IS NULL) THEN 
	camp_nul:= 'idDistribuidor';
	RAISE E_NUL;
ELSIF (p_nom IS NULL) THEN 
	camp_nul:= 'nom';
	RAISE E_NUL;
ELSIF (p_pais IS NULL) THEN 
	camp_nul:= 'pais';
	RAISE E_NUL;
ELSIF (p_esHomologat IS NULL) THEN 
	camp_nul:= 'esHomologat';
	RAISE E_NUL;
END IF;

--Verifica que existeix el distribudor
SELECT COUNT (*) INTO existeix
	FROM DISTRIBUIDOR
	WHERE idDistribuidor = p_idDistribuidor;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Modifica el distribudor
UPDATE DISTRIBUIDOR
	SET nom = p_nom,
		pais = p_pais,
		esHomologat = p_esHomologat
WHERE idDistribuidor = p_idDistribuidor;

--------------------------------------------------------------------------------------
-- 									ACTUALITZA EST4 								--
--------------------------------------------------------------------------------------

--Actualitza la taula EST4 un cop modificat el distribudor
SP_MODIFICACIO_EST4(); 
--------------------------------------------------------------------------------------

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: el distribudor no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
		ROLLBACK;

		IF (SQLCODE = -02290) THEN 
			RSP:= 'ERROR: el valor del camp esHomologat ha de ser SI/NO';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP); 
		
		ELSIF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix un distribudor amb el mateix: nom, pais.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_DISTRIBUIDOR', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_MODIFICACIO_DISTRIBUIDOR;