CREATE OR REPLACE PROCEDURE SP_ALTA_REGISTRE (
	p_producte			IN REGISTRE.producte%TYPE,
	p_pais				IN REGISTRE.pais%TYPE,
	p_distribuidor		IN REGISTRE.distribuidor%TYPE,
	p_cost				IN REGISTRE.cost%TYPE,
	p_dataInici			IN REGISTRE.dataInici%TYPE,
	p_dataFi			IN REGISTRE.dataFi%TYPE,
	p_durada			IN REGISTRE.durada%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_ALTA_REGISTRE
   Propsit:            afegeix un nou registre a la taula REGISTRE 
                   
   Parmetres entrada:  - p_producte NUMBER: identificador del producte
						- p_pais NUMBER: identificador del pas.
						- p_distribuidor NUMBER: identificador del distribudor.
                        - p_cost NUMBER: cost del registre.
						- p_dataInici DATE: data inici del registre.
						- p_dataFi DATE: data fi del registre.
						- p_durada NUMBER: duraci del trmits de registre.
						
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
ref_err			VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_FK			EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_producte: '||p_producte||
				', p_pais: '||p_pais||
				', p_distribuidor: '||p_distribuidor||
				', p_cost: '||p_cost||
				', p_dataInici: '||p_dataInici||
				', p_dataFi: '||p_dataFi||
				', p_durada: '||p_durada;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_producte IS NULL) THEN 
	camp_nul:= 'producte';
	RAISE E_NUL;
ELSIF (p_distribuidor IS NULL) THEN 
	camp_nul:= 'distribuidor';
	RAISE E_NUL;
ELSIF (p_pais IS NULL) THEN 
	camp_nul:= 'pais';
	RAISE E_NUL;
ELSIF (p_dataInici IS NULL) THEN 
	camp_nul:= 'dataInici';
	RAISE E_NUL;
END IF;

--Verifica que existeix el producte
SELECT COUNT (*) INTO existeix
	FROM PRODUCTE
	WHERE idProducte = p_producte;
	
	IF (existeix = 0) THEN
		ref_err:= 'producte'; 
		RAISE E_NO_FK;
	END IF;
	
--Verifica que existeix el pas
SELECT COUNT (*) INTO existeix
	FROM PAIS
	WHERE idPais = p_pais;
	
	IF (existeix = 0) THEN
		ref_err:= 'pais'; 
		RAISE E_NO_FK;
	END IF;

--Verifica que existeix el distribuidor
SELECT COUNT (*) INTO existeix
	FROM DISTRIBUIDOR
	WHERE idDistribuidor = p_distribuidor;
	
	IF (existeix = 0) THEN
		ref_err:= 'distribuidor'; 
		RAISE E_NO_FK;
	END IF;

-- Inserta el nou registre
INSERT INTO REGISTRE (resposta, producte, pais, distribuidor, cost, dataInici, dataFi, durada)
VALUES (DEFAULT, p_producte, p_pais, p_distribuidor, p_cost, p_dataInici, p_dataFi, p_durada);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_REGISTRE', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_REGISTRE', paramsEntrada, 'RSP: '||RSP);
		
	WHEN E_NO_FK THEN
		RSP:= 'ERROR: ' || ref_err || ' no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_REGISTRE', paramsEntrada, 'RSP: '||RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -02290) THEN 
			RSP:= 'ERROR: el valor dels camps cost i durada han de ser positius';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_REGISTRE', paramsEntrada, 'RSP: '||RSP); 
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_ALTA_REGISTRE', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_ALTA_REGISTRE;