CREATE OR REPLACE PROCEDURE SP_MODIFICACIO_PRODUCTE (
	p_idProducte		IN PRODUCTE.idProducte%TYPE,
	p_registrat			IN PRODUCTE.registrat%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_MODIFICACIO_PRODUCTE
   Propsit:            modifica un producte a la taula PRODUCTE. Un cop iniciat 
						el registre dun producte, aquest ja no es podr modificar. 
						Si es vol modificar shaur de donar de baixa i tornar-lo a 
						donar dalta (amb un nou registre).
                   
   Parmetres entrada:  - p_idProducte NUMBER: identificador del producte.
						- p_registrat NUMBER: estat del registre.
						
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_idProducte: '||p_idProducte||
				', p_registrat: '||p_registrat;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_idProducte IS NULL) THEN 
	camp_nul:= 'idProducte';
	RAISE E_NUL;
ELSIF (p_registrat IS NULL) THEN 
	camp_nul:= 'registrat';
	RAISE E_NUL;
END IF;

--Verifica que existeix el producte
SELECT COUNT (*) INTO existeix
	FROM PRODUCTE
	WHERE idProducte = p_idProducte;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Modifica les dades del producte
UPDATE PRODUCTE
	SET registrat = p_registrat
WHERE idProducte = p_idProducte;

--------------------------------------------------------------------------------------
-- 									ACTUALITZA EST6 								--
--------------------------------------------------------------------------------------

--Actualitza la taula EST6 un cop modificat el producte
SP_MODIFICACIO_EST6(); 
--------------------------------------------------------------------------------------

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_PRODUCTE', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_PRODUCTE', paramsEntrada, 'RSP: '||RSP);
		
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: el producte no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_PRODUCTE', paramsEntrada, 'RSP: '||RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
	
		IF (SQLCODE = -00001) THEN
			RSP:= 'ERROR: ja existeix un producte amb el mateix: nom, formula.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_PRODUCTE', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_PRODUCTE', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_MODIFICACIO_PRODUCTE;