CREATE OR REPLACE PROCEDURE SP_MODIFICACIO_REGISTRE (
	p_idRegistre		IN REGISTRE.idRegistre%TYPE,
	p_resposta			IN REGISTRE.resposta%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_MODIFICACIO_REGISTRE
   Propsit:            modifica les dades d'un registre de la taula REGISTRE.
						Un cop s'ha iniciat el registre, noms podem modificar
						la resposta.
                   
   Parmetres entrada:  - p_idRegistre NUMBER: identificador del registre
						- p_resposta NUMBER: estat del trmit.
                        - p_cost NUMBER: cost del registre.
						
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
codi			NUMBER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_idRegistre: '||p_idRegistre||
				', p_resposta: '||p_resposta;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_idRegistre IS NULL) THEN 
	camp_nul:= 'idRegistre';
	RAISE E_NUL;
ELSIF (p_resposta IS NULL) THEN 
	camp_nul:= 'resposta';
	RAISE E_NUL;
END IF;

--Verifica que existeix el registre
SELECT COUNT (*) INTO existeix
	FROM REGISTRE
	WHERE idRegistre = p_idRegistre;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Modifica les dades del registre
UPDATE REGISTRE
	SET resposta = p_resposta
WHERE idRegistre = p_idRegistre;

--Modifica la resposta al producte
SELECT producte INTO codi
	FROM REGISTRE
	WHERE idRegistre = p_idRegistre;
	
SP_MODIFICACIO_PRODUCTE(codi, p_resposta, RSP);

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_REGISTRE', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_REGISTRE', paramsEntrada, 'RSP: '||RSP);
		
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: el registre no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_REGISTRE', paramsEntrada, 'RSP: '||RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_MODIFICACIO_REGISTRE', paramsEntrada, 'RSP: '||RSP);

END SP_MODIFICACIO_REGISTRE;