CREATE OR REPLACE PROCEDURE SP_BAIXA_REGISTRE (
	p_idRegistre		IN REGISTRE.idRegistre%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_BAIXA_REGISTRE
   Propsit:            realitza la finalitzaci d'un registre. S'assigna 
                        la data actual com data de fi de registre.
                   
   Parmetres entrada:  - p_idRegistre NUMBER: identificador del registre.
						
   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
codi			NUMBER;
tipus_moneda	NUMBER;
duracio			NUMBER(10,4);
costTotal		NUMBER;
canvi			NUMBER;
productes		NUMBER;
pais_tramit		NUMBER;
paisos			NUMBER;
any_registre	NUMBER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

type r_cursor IS REF CURSOR;
CUR r_cursor;

BEGIN
   
paramsEntrada:= 'p_idRegistre: '||p_idRegistre;
   
--Verifica que els camps obligatoris no siguin nuls
IF (p_idRegistre IS NULL) THEN 
	camp_nul:= 'idRegistre';
	RAISE E_NUL;
END IF;

--Verifica que existeix el registre
SELECT COUNT (*) INTO existeix
	FROM REGISTRE
	WHERE idRegistre = p_idRegistre;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

--REALITZA LA FINALITZACI DEL REGISTRE
--S'assigna la data actual com DATA de FI de registre.
UPDATE REGISTRE
	SET dataFi = SYSDATE
	WHERE idRegistre = p_idRegistre AND dataFi IS NULL;
	
--Es modifica la resposta al registre i al producte
SELECT producte INTO codi
	FROM REGISTRE
	WHERE idRegistre = p_idRegistre;
	
SP_MODIFICACIO_REGISTRE(codi, 1, RSP);

--Calculem el temps que ha durat el registre i el seu cost (100/dia)
SELECT to_date(dataFi,'DD/MM/YYYY HH24:MI:SS') - to_date(dataInici,'DD/MM/YYYY HH24:MI:SS') INTO duracio
	FROM REGISTRE
	WHERE idRegistre = p_idRegistre;

UPDATE REGISTRE
	SET durada = duracio
	WHERE idRegistre = p_idRegistre;
	
costTotal := duracio * 100;

--Comprovem la moneda a utilitzar
SELECT p.moneda INTO tipus_moneda
	FROM PAIS p, REGISTRE r
	WHERE p.idPais = r.pais AND r.idRegistre = p_idRegistre;
	
--Actualitzem la taula COST
SP_ALTA_COST(codi, costTotal, tipus_moneda, RSP);

--S'actualitza el COST del registre
SELECT cost INTO canvi
	FROM COST
	WHERE producte = codi;
	
UPDATE REGISTRE
	SET cost = canvi
	WHERE idRegistre = p_idRegistre;
	
--Comprovem el pas on es realitza el tramit
SELECT pais INTO pais_tramit
	FROM REGISTRE
	WHERE idRegistre = p_idRegistre;
	
--------------------------------------------------------------------------------------
-- 									ACTUALITZA EST1 								--
--------------------------------------------------------------------------------------

--Calcula si ja existeixen 10 productes a la taula EST1
SELECT COUNT (*) INTO productes
	FROM EST1_PROD_COST;
   
--Comprova si el producte existeix a la taula EST1
SELECT COUNT (*) INTO existeix
	FROM EST1_PROD_COST;  
   
--Si el producte no existeix i la taula te menys de 10 entrades, afegeix el producte
IF (productes < 10 AND existeix = 0) THEN 
	SP_ALTA_EST1(codi, costTotal);
--En cas contrari actualitza la taula
ELSE
	SP_MODIFICACIO_EST1(); 
END IF;
--------------------------------------------------------------------------------------

--------------------------------------------------------------------------------------
-- 									ACTUALITZA EST2 								--
--------------------------------------------------------------------------------------

--Calcula si ja existeixen 10 paisos a la taula EST2
SELECT COUNT (*) INTO paisos
	FROM EST2_PAISOS_TRAM_LENT;
   
--Comprova si el pais existeix a la taula EST2
SELECT COUNT (*) INTO existeix
	FROM EST2_PAISOS_TRAM_LENT;  
   
--Si el pais no existeix i la taula te menys de 10 entrades, afegeix el pas
IF (paisos < 10 AND existeix = 0) THEN 
	SP_ALTA_EST2(pais_tramit, duracio);
--En cas contrari actualitza la taula
ELSE
	SP_MODIFICACIO_EST2(); 
END IF;
--------------------------------------------------------------------------------------

--------------------------------------------------------------------------------------
-- 									ACTUALITZA EST3 								--
--------------------------------------------------------------------------------------

--Comprova si el pais existeix a la taula EST3
SELECT COUNT (*) INTO existeix
	FROM EST3_TEMPS_MIG
	WHERE pais = pais_tramit;
   
--Si no existeix el pas, l'afegeix a la taula 
IF (existeix = 0) THEN 
	SP_ALTA_EST3(pais_tramit, duracio);   
--En cas contrari actualitza la taula
ELSE
	SP_MODIFICACIO_EST3();
END IF;
--------------------------------------------------------------------------------------

--------------------------------------------------------------------------------------
-- 									ACTUALITZA EST5 								--
--------------------------------------------------------------------------------------

--Calcula l'any del registre
SELECT EXTRACT(year FROM dataFi) INTO any_registre
	FROM REGISTRE
	WHERE idRegistre = p_idRegistre;

--Calcula el identificador del pas.
OPEN CUR FOR
	SELECT DISTINCT pais INTO pais_tramit 
	FROM REGISTRE
	WHERE idRegistre = p_idRegistre;
      
--Per cada pas relacionat:
		LOOP
			FETCH CUR INTO pais_tramit;
			EXIT WHEN CUR%NOTFOUND;

--Calcula si existeix una entrada a la taula per al pas a l'any del registre.
			SELECT COUNT (*) INTO existeix
				FROM EST5_MIG_REG_PAIS
				WHERE pais = pais_tramit AND anys = any_registre;

--Si no existeix l'entrada, l'afegeix a EST5
			IF (existeix = 0) THEN 
				SP_ALTA_EST5(pais_tramit, any_registre, 1);
         
--Si existeix, actualitza la entrada.
			ELSE
				SP_MODIFICACIO_EST5(pais_tramit, any_registre);
			END IF;
			
		END LOOP;  
CLOSE CUR; 
--------------------------------------------------------------------------------------

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_REGISTRE', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_REGISTRE', paramsEntrada, 'RSP: '||RSP);
		
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: el registre no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_REGISTRE', paramsEntrada, 'RSP: '||RSP);
	
	WHEN OTHERS THEN
		ROLLBACK;
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_REGISTRE', paramsEntrada, 'RSP: '||RSP);

END SP_BAIXA_REGISTRE;