CREATE OR REPLACE PROCEDURE SP_BAIXA_PRODUCTE (
	p_idProducte		IN PRODUCTE.idProducte%TYPE,
	RSP					OUT VARCHAR2
)
IS
/******************************************************************************
   Nom:                 SP_BAIXA_PRODUCTE
   Propsit:            elimina un producte a la taula PRODUCTE 
                   
   Parmetres entrada:  - p_idProducte NUMBER: identificador del producte.

   Parmetres sortida:  RSP
   Retorna:             'OK' si l'execuci ha finalitzat amb xit
                        'ERROR: tipus d'error' si ha fracassat
******************************************************************************/
paramsEntrada	VARCHAR2(500);
existeix		INTEGER;
err_msg			VARCHAR2(200);
camp_nul		VARCHAR2(20);
E_NUL			EXCEPTION;
E_NO_EXISTEIX	EXCEPTION;

BEGIN
   
paramsEntrada:= 'p_idProducte: '||p_idProducte;

--Verifica que els camps obligatoris no siguin nuls
IF (p_idProducte IS NULL) THEN 
	camp_nul:= 'idProducte';
	RAISE E_NUL;
END IF;

--Verifica que existeix el producte
SELECT COUNT (*) INTO existeix
	FROM PRODUCTE
	WHERE idProducte = p_idProducte;
	
	IF (existeix = 0) THEN
		RAISE E_NO_EXISTEIX;
	END IF;

-- Elimina el producte
DELETE FROM PRODUCTE WHERE idProducte = p_idProducte;

--------------------------------------------------------------------------------------
-- 									ACTUALITZA EST6 								--
--------------------------------------------------------------------------------------

--Actualitza la taula EST6 un cop donat de baixa el producte
SP_MODIFICACIO_EST6(); 
--------------------------------------------------------------------------------------

-- Finalitza amb xit
RSP:= 'OK';
SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_PRODUCTE', paramsEntrada, 'RSP: '||RSP);

COMMIT;

EXCEPTION

	WHEN E_NUL THEN
		RSP:= 'ERROR: el camp ' || camp_nul || ' no pot ser nul'; 
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_PRODUCTE', paramsEntrada, 'RSP: '||RSP);
	
	WHEN E_NO_EXISTEIX THEN
		RSP:= 'ERROR: el producte no existeix';
		SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_PRODUCTE', paramsEntrada, 'RSP: '||RSP);

	WHEN OTHERS THEN
	ROLLBACK;
		IF (SQLCODE = -02292) THEN
			RSP:= 'ERROR: no es pot esborrar el producte perqu esta en procs de registre.';
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_PRODUCTE', paramsEntrada, 'RSP: '||RSP);
			
		ELSE
			err_msg := SUBSTR (SQLERRM, 1, 200);
			RSP:= 'ERROR: ' || err_msg;
			SP_ALTA_LOGS(to_char(sysdate,'DD/MM/YYYY HH24:MI:SS'), 'SP_BAIXA_PRODUCTE', paramsEntrada, 'RSP: '||RSP);
		END IF;

END SP_BAIXA_PRODUCTE;